@@ -13,7 +13,7 @@ import scipy.stats as stats
 import matplotlib
 
 
-def load_raw_data(path,dtype,length,time='Random',*args):
+def load_raw_data(path,dtype,length,time='Random',analog=False,*args):
     """
     Load data from the raw files (e.g., .ncs for Neuralynx)
 
@@ -41,6 +41,9 @@ def load_raw_data(path,dtype,length,time='Random',*args):
         By default take randomly portion of signal corresponding to length
         It can be a tuple (2,7) for example to take signal from 2 minutes to 7 minutes of the recording
     
+    analog: string (optional) (Default: False)
+        Reference channel used in blackrock recording system if exist
+    
     
     Returns
     ---------------------------
@@ -59,8 +62,9 @@ def load_raw_data(path,dtype,length,time='Random',*args):
     # Load 'ns5' from Blackrock    
     elif dtype=='nsX':
         raw_data = mne.io.read_raw_nsx(path)
-        # Exclude the reference channel
-        raw_data.drop_channels('ainp1')
+        if analog:
+            # Exclude the reference channel
+            raw_data.drop_channels(analog)
     elif dtype=='dat':
         # Here not sure everyone is using int16 but for us it is ok
         data_type = np.int16
@@ -214,7 +218,7 @@ def splitCharNum(string) :
         string containing only the numbers from the input (e.g., '1')
     """
     import re
-    char,number=re.findall(r'[A-Za-z-_]+|\d+', string)
+    char,number=re.findall(r'[A-Za-z-_\']+|\d+', string)
     return char,number
 
 
